<p align="center">
    <img src="session/towns-of-malaya.jpg" alt="malaya logo" />
</p>

# Malaya ![alt text](https://s3.amazonaws.com/assets.coveralls.io/badges/coveralls_98.svg)
Natural-Language-Toolkit for bahasa Malaysia, powered by Deep Learning.

## How-to-Start

All the documentations moved to [Malaya Wiki](https://github.com/DevconX/Malaya/wiki).

## Contributors

* **Husein Zolkepli** - *Initial work* - [huseinzol05](https://github.com/huseinzol05)

* **Sani** - *build PIP package* - [khursani8](https://github.com/khursani8)
